summaryrefslogtreecommitdiffstats
path: root/sys/i386
diff options
context:
space:
mode:
authordavidxu <davidxu@FreeBSD.org>2006-10-17 02:24:47 +0000
committerdavidxu <davidxu@FreeBSD.org>2006-10-17 02:24:47 +0000
commitbb5a3880aaba619ef92556240b090b17a430f444 (patch)
treeb31b5290e903f0eb1069077900871403a7ca78f8 /sys/i386
parentc0e6d5e6651f1b6140e24533f47bd20e2ca2952d (diff)
downloadFreeBSD-src-bb5a3880aaba619ef92556240b090b17a430f444.zip
FreeBSD-src-bb5a3880aaba619ef92556240b090b17a430f444.tar.gz
o Add keyword volatile for user mutex owner field.
o Fix type consistent problem by using type long for old umtx and wait channel. o Rename casuptr to casuword.
Diffstat (limited to 'sys/i386')
-rw-r--r--sys/i386/i386/support.s4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/i386/i386/support.s b/sys/i386/i386/support.s
index aee43a4..bacf506 100644
--- a/sys/i386/i386/support.s
+++ b/sys/i386/i386/support.s
@@ -1140,11 +1140,11 @@ fastmove_tail_fault:
#endif /* I586_CPU && defined(DEV_NPX) */
/*
* casuptr. Compare and set user pointer. Returns -1 or the current value.
*/
ALTENTRY(casuword32)
-ENTRY(casuptr)
+ENTRY(casuword)
movl PCPU(CURPCB),%ecx
movl $fusufault,PCB_ONFAULT(%ecx)
movl 4(%esp),%edx /* dst */
@@ -1140,11 +1140,11 @@ fastmove_tail_fault:
#endif /* I586_CPU && defined(DEV_NPX) */
/*
- * casuptr. Compare and set user pointer. Returns -1 or the current value.
+ * casuword. Compare and set user word. Returns -1 or the current value.
*/
ALTENTRY(casuword32)
OpenPOWER on IntegriCloud